@@ -2,7 +2,7 @@ QE <-
 function (comm, dis = NULL, formula = c("QE", "EDI"), scale = FALSE) 
 {
     if (!inherits(comm, "data.frame") & !inherits(comm, "matrix")) 
-        stop("Non convenient comm")
+        stop("comm must be a data frame or a matrix")
     comm <- t(comm)
     if (any(comm < 0)) 
         stop("Negative value in comm")
@@ -10,10 +10,10 @@ function (comm, dis = NULL, formula = c("QE", "EDI"), scale = FALSE)
     formula <- formula[1]
     if (!is.null(dis)) {
         if (!inherits(dis, "dist")) 
-            stop("Object of class 'dist' expected for distance")
+            stop("Object of class 'dist' expected for dis")
         dis <- as.matrix(dis)
         if (nrow(comm) != nrow(dis)) 
-            stop("Non convenient comm")
+            stop("Species in comm (columns) must be the same as in dis")
         dis <- as.dist(dis)
         if(formula=="QE") dis <- sqrt(2*dis)
     }
@@ -22,7 +22,7 @@ function (comm, dis = NULL, formula = c("QE", "EDI"), scale = FALSE)
     }
     div <- as.data.frame(rep(0, ncol(comm)))
     names(div) <- "diversity"
-    rownames(div) <- names(comm)
+    rownames(div) <- colnames(comm)
     for (i in 1:ncol(comm)) {
         if (sum(comm[, i]) < 1e-16) 
             div[i, ] <- 0
@@ -33,5 +33,6 @@ function (comm, dis = NULL, formula = c("QE", "EDI"), scale = FALSE)
         divmax <- divcmax(dis)$value
         div <- div/divmax
     }
+    rownames(div) <- colnames(comm)
     return(div)
 }
